{% extends "admin/base.html" %}
{% load i18n staticfiles %}

{% block extrastyle %}{% include 'admin/inc/extrastyle.html' %}{% endblock %}

{% block extrahead %}<link rel="stylesheet" type="text/css" href="{% static 'djangocms_admin_style/css/djangocms-admin.css' %}" />
<meta name="viewport" content="width=device-width,initial-scale=1" />
<script type="text/javascript">
if (window.self!==window.top) { document.write('<link rel="stylesheet" type="text/css" href="{% static 'djangocms_admin_style/css/djangocms-admin-frontend.css' %}" />'); }
</script>
{% include 'admin/inc/extrahead.html' %}{% endblock %}

{% block title %}{% include 'admin/inc/title.html' %}{% endblock %}

{% block branding %}{% include 'admin/inc/branding.html' %}{% endblock %}

{% block userlinks %}{% include 'admin/inc/userlinks.html' %}{{ block.super }}{% endblock %}
