table {
	@include border-radius(); background: $background-color-white; border: none;
	margin: 20px 0; padding: 5px; width: 100%;
	th { border-bottom: 1px solid $line-color-light; }
	th, td { padding: 5px 10px; text-align: left; vertical-align: middle; }
	thead th, thead th.sorted, tfoot td { background: $background-color-ultralight; }
	thead th.sortable:hover { background: $background-color-light; }
	td, th { font-family: $base-font-family; padding: 5px; }
	td.original { vertical-align: top; }
	tr {
		td { border-bottom: 1px solid $line-color-ultralight; }
	}
	th {
		a, a:link, a:visited, a:link:visited { color: $font-color; }
	}
	.row1 { background: $background-color-white; }
	.row2 { background: $background-color-ultralight; }
}
fieldset table { border: none; }
.results table tbody tr:hover { background: $background-color-highlighter; }
