
// containers
#container { width: auto !important; min-width: 0 !important; }
#content { width: auto !important; min-width: 0 !important; }
#changelist { width: auto !important; }

// module
.module {
	@include box(); margin-bottom: 10px; padding: 10px 15px 15px;
	h2 { background: none; border-bottom: 1px solid $line-color-light; color: $font-color; font-size: 100%;
		margin-bottom: 2px;	margin-top: 0; padding: 10px; }
	caption {
		background: none; color: $font-color-light; font-size: 130%; font-weight: bold;
		line-height: 1.75em; margin: 0 0 5px 5px; padding: 0;
		a.section, a.section:link, a.section:visited { color: $font-color-light; }
	}
	table {
		margin: 0;
		th { padding: 2px 5px !important; line-height: 13px; }
		td { padding: 8px 5px; line-height: 13px; }
	}
}

// inlines
.module h2, .module caption, .inline-group h2 { background: none; color: $font-color-dark; font-size: 16px; }
.inline-group {
	border: 0; @include box(); padding: 10px 15px 15px;
	.module {
		background: none !important; @include border-radius(0); @include box-shadow(none); border: none !important;
		padding: 0;
		h2 { margin-bottom: 10px; padding-top: 0; padding-bottom: 8px; }
		.add-row a { border-bottom: none; color: $button-green-dark-color; }
		.add-row td { background: none; border-bottom: none; }
		tr.add-row:hover { background: none; }
		.form-row { border-bottom: none !important; }
	}
	.module { width: 100%; overflow: auto; }
	.add-row {
		&, td { border-bottom: none; background: none !important; }
		a { color: $button-green-dark-color; }
	}
}
.inline-related {
	margin-bottom: 5px;
	h3 { background: none; border-bottom: none; }
}
.submit-row {
	@include border-radius(); border: 1px solid $line-color-light; padding: 10px;
	@include box-shadow($background-color-white 0 0 $button-shadow-width inset !important);
	background: $background-color-light;
	background: $background-color-transparent !important;
	.deletelink-box { line-height: 24px; }
	.deletelink { @include button-common(); @include button-red(); }
	input[type="submit"].default { margin-left: 10px; }
}

// filter horizontal m2m
.selector {
	.selector-available, .selector-chosen {
		@include border-radius(); border: 1px solid $line-color-light;
		h2 { color: $font-color !important; background: none !important; border: none; margin-bottom: 0;
			font-size: 13px; line-height: 16px; }
		input { width: 252px; margin: -5px 0 2px 0; }
	}
	.selector-filter { border: none; }
	.selector-filter label { display: none; }
	select[multiple] { border: 1px solid $line-color-light; border-left: none; border-right: none;
		margin-bottom: 0; }
}

// login
body.login {
	background: $background-color-ultralight url('../img/bg-pattern.jpg') repeat !important;
	#container {
		@include box(); border: none; width: 340px !important;
		@include box-shadow(rgba(0, 0, 0, 0.3) 0px 1px 2px, #fff 0px 1px 1px inset);
		#header {
			background: none !important;
			#branding h1 { color: $font-color; margin: 20px 0 !important; text-align: center; }
		}
		#content {
			margin: 0 !important; padding: 25px 40px !important;
			#content-main {
				form { margin-top: 0 !important; }
				.form-row {
					label { font-weight: normal; width: 100%; text-align: center; }
					input { font-size: 16px; padding: 10px; width: 240px !important; }
				}
				.submit-row {
					border: none; background: none; padding: 20px 0 0 0;
					input, input[type="submit"] { background-image: none; @include button-blue();
						width: 262px !important; }
					label { display: none; }
				}
			}
		}
		#footer { display: none; }
	}
}

// header
#header {
	@include background-image(linear-gradient($background-color-dark, $background-color-medium));
	background-color: $background-color-medium; color: $font-color-white !important; height: 46px;
	#branding h1 { color: $font-color-white; padding: 3px 25px; }
	#user-tools { padding: 16px 25px 0; }
}
div.breadcrumbs {
	background: $background-color-dark; border-top: 1px solid $line-color-dark; color: #ddd; padding-left: 25px;
	border-bottom: 0; padding-bottom: 4px;
	a {
		color: #bbb;
		&:hover { color: $font-color-ultralight; text-decoration: none; }
	}
}

// dashboard
.dashboard #container {
	#content-main {
		min-width: 400px; max-width: 640px;
		table th, table td {
			width: auto; border-color: $line-color-ultralight;
			a { line-height: 16px; }
		}
		table th { width: 100%; }
		.module tr:first-child { th, td { border-top:1px solid $line-color-ultralight; } }
	}
	#content-related {
		float: left;
		.module { @include border-radius(); border: 1px solid $line-color-light; margin-left: 10px;
			@include box-shadow($background-color-white 0 0 $button-shadow-width inset !important);
			background: $background-color-transparent !important; padding: 10px 20px !important;
			ul.actionlist {
				padding: 0;
				.changelink a { line-height: 16px; }
			}
			h2 { background: none; color: $font-color-light; padding: 0 0 5px 0; }
			h3 { border-bottom: 1px solid $line-color-light; line-height: 20px; margin: 0 0 5px 0; padding: 0; }
			p { padding: 0; }
		}
	}
	table tbody tr:hover { background: none; }
}

a.addlink {
	&, &:link, &:visited { color: $button-green-medium-color; }
	&:hover, &:focus, &:active { color: $button-green-dark-color; }
}

// object tools
.object-tools {
	margin-top: -38px;
	li {
		list-style: none; background: none; padding-left: 5px; height: 32px;
		&:hover { background: none; }
		> a { @include button-common(); }
	}
	.addlink { @include button-common(); @include button-green(); color: $button-green-font-color !important; }
	.recoverlink { @include button-common(); }
	.publishlink { @include button-common(); }
	.previewdraftlink { @include button-common(); }
	.revertlink { @include button-common(); }
	.historylink { @include button-common(); }
	.viewsitelink { @include button-common(); @include button-blue(); }
}

// changelist
.change-list {
	.filtered {
		min-height: auto; background-image: none !important;
		table { border: none; }
	}
	#changelist {
		table {
			tbody {
				th, td {
					a, a:link, a:visited, a:link:visited { color: $link-color; }
					border-color: $background-color-light;
				}
				tr.selected { background: $background-color-highlight !important; }
			}
		}
		#toolbar {
			background: none !important; border: 0 !important; margin: 0 0 5px 0; min-height: 30px; height: auto;
			form label { min-width: auto; padding: 0; font-size: 100%; }
			form #searchbar { padding: 6px 5px 8px 5px !important; font-size: 100%; }
		}
		#changelist-filter {
			min-height: 100%; background: #fafafa; @include border-top-right-radius(); @include border-bottom-right-radius();
			h2 { background: none; color: $font-color-light; padding: 2px 9px; }
			h3 { margin: 5px 0; }
			ul {
				font-size: 12px; margin-bottom: 10px;
				li { margin-bottom: 2px; }
				li.selected a { color: $link-color !important; }
			}
		}
		.actions {
			background: none; border: none; padding: 0px 3px 10px 3px;
			button { height: 20px; vertical-align: middle; padding-top: 2px !important; }
		}
		.toplinks { border-bottom: none !important; background: none; margin-bottom: 5px !important; }
		.paginator { border: none; background: none; }
	}
}

// changeform
.change-form {}

// delete page
.delete-confirmation .colM {
	@include box(); padding: 20px; margin: 15px !important;
	h1 { margin: 0 0 10px 0; }
	li { line-height: 16px; }
	input[type="submit"] { @include button-red(); float: right; }
}

// cms pagelist
#sitemap li a.addlink, #sitemap li a.deletelink { width: 11px; height: 11px; }
.tree {
	.col1 .changelink { float: left; line-height: 16px !important; margin: 6px 0 0 15px !important; }
}

// cms language buttons
#page_form_lang_tabs input {
	@include border-bottom-radius(0); @include box-shadow(none !important);
	background: #ccc !important; color: $font-color-medium !important; font-weight: normal !important;
	border: none !important; margin: 0;
	&:hover, &:focus { color: black !important; }
	&.selected { background: white !important; color: black !important; }
	&.notfilled { background: $background-color-light !important; color: #bbb !important; }
}
#lang_tab_content h2.header { background: $button-blue-light-color !important; @include border-top-right-radius();
	margin-bottom: -3px !important; position: relative; }


// nani/hvad language buttons
.nani-language-tabs {
	border-bottom: 5px solid $button-blue-light-color; margin-bottom: -3px; position: relative;
	> span {
		@include inline-block(); border: none !important; top: 0 !important; color: $font-color-medium !important;
		font-weight: normal !important; vertical-align: top; background: white; padding: 8px 10px !important;
		margin: 0 !important; @include border-top-radius();
		a {
			color: $font-color-medium !important; padding: 5px 10px;
			&:hover, &:focus { color: black !important; text-decoration: none; }
		}
		.deletelink { display: inline; padding: 0 0 0 12px !important; margin: 0; @include border-top-radius(0);
			background: url('../img/icon_deletelink.png') 0 .25em no-repeat !important; bottom: 0px !important;
			right: -3px !important; }
	}
	> .empty { opacity: 1 !important; background: $background-color-light; color: $font-color-light; }
	> .current { background: $button-blue-light-color; color: white !important; padding-left: 20px !important;
		padding-right: 20px !important; @include text-shadow(0 1px 1px rgba(0,0,0,0.2)); }
	> .current .deletelink { right: -12px !important; }
}
.inline-group .nani-language-tabs {
	margin-bottom: 0;
	> span { padding: 4px 10px !important; }
	> .current { padding-left: 20px !important; padding-right: 20px !important; }
	> .available { background: #eee; }
}

