// django-admin-shortcuts
.admin_shortcuts .shortcuts {
	@include box-shadow(none); background: $background-color-dark; border-top: 1px solid $line-color-dark;
	color: $font-color-ultralight;
	h2 { border: none; font-weight: normal; }
	li {
		a, a:link, a:visited {
			background-color: $background-color-medium; border: 1px solid $line-color-dark; text-decoration: none;
			.count { color: $font-color-light; }
			.count_new { background: $button-blue-medium-color; border-color: $button-blue-light-color; }
		}
		a:hover, a:focus { background-color: #4e5359; }
		a:active { background-color: $background-color-medium; }
	}
}

