
.addlink, .changelink, .deletelink { padding-left: 15px; }

.deletelink { background-image: url('../img/icon_deletelink.png'); }

.related-lookup, .add-another {
	margin: 0 5px;
	&:hover, &:focus, &:active { text-decoration: none !important; }
}
.add-another { @include hide-text(); @include inline-block(); width: 14px; height: 14px;
	background: url('../img/icon_addlink_large.gif') 0 0 no-repeat; }

.tree .changelink { background-image: url('../img/icon_changelink_white.png'); }

#sitemap li .col-softroot span.icon { background: url('../img/icon_softroot.png') 0 0 no-repeat;
	width: 15px; height: 15px; margin: 7px 5px 0 0; }

// retina
@media only screen and (-webkit-min-device-pixel-ratio:2),
only screen and (-o-min-device-pixel-ratio:2),
only screen and (min--moz-device-pixel-ratio:2),
only screen and (min-device-pixel-ratio:2) {
	.addlink { background-image: url('../img/icon_addlink@2x.gif'); background-size: 11px; }
	.changelink { background-image: url('../img/icon_changelink@2x.gif'); background-size: 11px; }
	.tree .changelink { background-image: url('../img/icon_changelink_white@2x.png'); background-size: 11px; }
	.deletelink { background-image: url('../img/icon_deletelink@2x.png'); background-size: 11px; }
	#sitemap li .col-softroot span.icon { background-image: url('../img/icon_softroot@2x.png'); background-size: 15px; }
	.related-lookup { @include hide-text(); @include inline-block(); width: 16px; height: 16px;
		background: url('../img/icon_searchbox@2x.png') 0 0 no-repeat; background-size: 16px; }
	.add-another { @include hide-text(); @include inline-block(); width: 14px; height: 14px;
		background: url('../img/icon_addlink_large@2x.gif') 0 0 no-repeat; background-size: 14px; }
}
