// base

body { background: url('../img/bg-pattern-light.jpg') #efefef repeat !important; }

body, select, input, textarea { color: $font-color; }

h1 { font-size: 150%; color: $font-color-medium; font-weight: bold; margin: 20px 10px 10px;  }
h2 { font-size: 130%; color: $font-color-medium; font-weight: bold; line-height: 1.75em;}
h3 { font-size: 120%; color: $font-color; font-weight: bold; }
h4 { font-size: 110%; color: $font-color-medium; font-weight: bold;}
h5 { font-size: 100%; color: $font-color; }
h6 { font-size: 100%; color: $font-color-medium; }

a, a:link {
	color: $link-color;
	text-decoration: none;
	&:visited { color: $link-visited-color; }
	&:hover { color: $link-hover-color; text-decoration: underline; }
	&:active { color: $link-active-color; }
}

p { font-weight: normal; margin-bottom: 6px; }

code {
	font-family: "Bitstream Vera Sans Mono", Monaco, "Courier New", Courier, monospace; background: inherit;
	color: #666; font-size: 11px;
	strong { color: #930; }
}

pre {
	font-family: "Bitstream Vera Sans Mono", Monaco, "Courier New", Courier, monospace; background: inherit;
	color: #666; font-size: 11px;
	&.literal-block { background: #eee; }
}

div hr { background: $line-color-light; margin: 20px 0; border: none; }

strong { font-weight: bold; }
.small, small { font-size: 85%; margin-top: 0; }

.clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }


