/* Use the following CSS code if you want to have a class per icon */
.addlink,
.changelink,
#changelist-search label,
.deletelink,
a.selector-clearall,
a.active.selector-clearall,
a.selector-chooseall,
a.active.selector-chooseall,
.selector-remove,
.selector-add,
.inline-group .add-row a,
a[id^="calendarlink"],
a[id^="clocklink"]
{
	background: none !important;
	padding-left: 10px;
	line-height: 10px;
	&:hover {
		text-decoration: none !important;
	}
	
}

.addlink:before,
.changelink:before,
#changelist-search label:before,
.deletelink:before,
a.selector-clearall:before,
a.active.selector-clearall:before,
a.selector-chooseall:before,
a.active.selector-chooseall:before,
.selector-remove:before,
.selector-add:before,
.inline-group .add-row a:before,
.add-another:before,
a[id^="calendarlink"]:before,
a[id^="clocklink"]:before
{
	font-family: 'django-admin-icons';
	font-style: normal;
	speak: none;
	font-weight: normal;
	font-size: 75%;
	-webkit-font-smoothing: antialiased;
	padding-right: 5px;
}


.addlink:before { content: "\22";  }
.changelink:before { content: "\21"; }
#changelist-search label:before { content: "\23"; }
.deletelink:before { content: "\24"; }
.selector-remove:before, a.selector-clearall:before, a.active.selector-clearall:before { content: "\25"; font-size: 100%; }
.selector-add:before, a.selector-chooseall:before, a.active.selector-chooseall:before { content: "\26"; font-size: 100%; }
.inline-group .add-row a:before { content: "\22";  }
.add-another:before { content: "\22";  }
a[id^="calendarlink"]:before { content: "\2c";  }
a[id^="clocklink"]:before { content: "\2d"; }

.actionlist {
	.addlink, .changelink { padding-left: 0; }
}

#changelist-search label { font-weight: bold; }
#changelist-search label img { display: none;}
.help-tooltip { display: none; }
a.active.selector-chooseall {  }
.selector-remove, .selector-add { display: inline !important; font-size: 125% !important; padding-left: 1px; color: $font-color-white !important; }
.selector-remove:before, .selector-add:before { color: $font-color; }
.inline-group .add-row a { color: $success-color !important; padding-left: 5px !important; }

.add-another { 
	margin-left: 10px; 
	&:hover, &:link:hover {
		text-decoration: none;
	}
}
.add-another img { display: none; }


a[id^="calendarlink"], a[id^="clocklink"] {
	display: inline-block;
	font-size: 19px;
	height: 19px;
	width: 19px;
	padding-left: 0 !important; 
}
a[id^="calendarlink"] img, , a[id^="clocklink"] img { display: none;}

/* Sepcials */
.selector ul.selector-chooser { @include border-radius(10px); background: $background-color-light !important; height: 44px !important; }
