// base
html, body { height: auto; }
#content { margin: 0 5px; }
#container { margin: 0; min-width: 240px !important; }
#branding { display: none; }
.login #branding { display: block; }
#user-tools { position: relative; text-align: center; }

// general
.module {
	border: none; box-shadow: none; padding: 5px 0 5px 0 !important;
	@include box-shadow(none !important);
	caption { margin-bottom: 5px; margin-left: 5px; }
}
div.breadcrumbs { padding-left: 5px; }
.plugin-holder { display: none !important; }

// login
body.login {
	#container {
		width: auto !important; max-width: 320px;
		#content #content-main {
			.form-row, .submit-row { text-align: center; }
			.form-row input { width: auto !important; max-width: none; min-width: 40px; }
			.submit-row input, .submit-row input[type="submit"] { width: 80% !important; }
		}
	}
}

// dashboard
.colMS { margin-right: 10px !important; }
.dashboard {
	#container {
		#content h1 { display: none; }
		#content-main {
			min-width: 0; max-width: none; float: none;
			.addlink, .changelink { text-indent: -9999px; overflow: hidden; }
		}
		#content-related { width: auto; float: none; margin-right: 0; }
		#content-related .module {
			padding: 10px !important; margin: 10px 0;
			.actionlist { margin-left: 10px; }
		}
	}
	.module { background: none !important; }
}

// changelist
.change-list #content {  }
.change-list {
	#content {
		margin-top: 38px;
		> h1 { display: none; }
		.object-tools { margin: -33px 0 0 0; }
		.filtered {  }
	}
	#toolbar {
		label { display: inline-block; }
		form #searchbar { width: 120px; }
		.small { display: block; }
	}
	.filtered .results, .change-list .filtered .paginator, .filtered #toolbar, .filtered div.xfull {
		margin-right: 0 !important; }
	.module #changelist-form .results { width: 100%; overflow: auto; }
	.filtered {
		.actions, .paginator { margin-right: 0 !important; }
	}
}
#changelist-filter-button, #changelist-filter { display: none !important; }
.tree { background: white; }

// page tree
#sitemap li .col-softroot, #sitemap li .col-language, #sitemap li .col-actions, #sitemap li .col-published,
#sitemap li .col-navigation, #sitemap li .col-moderator, #sitemap li .col-lastchange, #sitemap li .col-draft,
#sitemap li .col-view-perms, #sitemap li .col-creator { display: none !important; }

#sitemap li .col-softroot, #sitemap li .col-language { display: block !important; }

// chageform
.change-form {
	#content {
		margin-top: 45px;
		> h1 { display: none; }
	}
	.object-tools { margin: -35px 0 0 0; }
}

// cms language buttons
#page_form_lang_tabs input { font-weight: normal !important; font-size: 11px !important; padding: 2px 4px !important; }
// nani/hvad language buttons
.nani-language-tabs {
	> span {
		font-size: 11px !important; padding: 4px 1px !important;
		a { padding: 3px 5px !important; }
		.deletelink { right: 0 !important; }
	}
	> .current {
		padding: 4px 10px 4px 5px !important;
		.deletelink { right: -8px !important; }
	}
}

// forms
form label, .aligned label { display: block; padding: 0 !important; float: none !important;
	line-height: 14px; margin-top: 5px; width: auto; }
form {
	input, input[type="file"], textarea, select { width: auto; /*max-width: 200px;*/ }
	.vTextField { width: auto; }
	.aligned p, .aligned ul { padding-left: 0 !important; margin-left: 0 !important; }
	.submit-row { text-align: left; }
}

// inlines
.inline-group {
	padding: 5px; margin-bottom: 10px;
	.module {
		h2 { padding-left: 5px; }
	}
}

// filter horizontal m2m
.selector {
	width: auto; float: none;
	.selector-available, .selector-chosen {
		width: auto; float: none;
		p { text-align: center; }
	}
	.selector-chosen { margin-top: 60px; }
	ul.selector-chooser { margin-top: 0; display: block; }
	select[multiple], select { max-width: none; width: 100%; }
	label { display: inline-block; }
	.selector-available input, .selector-chosen input { width: auto; }
}

// shortcuts
.admin_shortcuts .shortcuts li a { background-size:20px 20px; padding:10px 10px 10px 40px; }
.admin_shortcuts .shortcuts li a span { padding:0 !important; }
.admin_shortcuts .shortcuts li:first-child a { padding:10px 20px; }
